@@ -1,4 +1,5 @@
 import json
+from typing import Type
 from velocity.aws.handlers.base_handler import BaseHandler
 from velocity.aws.handlers.response import Response
 from . import context
@@ -8,7 +9,12 @@ from . import context
 
 
 class LambdaHandler(BaseHandler):
-    def __init__(self, aws_event, aws_context, context_class=context.Context):
+    def __init__(
+        self, 
+        aws_event, 
+        aws_context, 
+        context_class: Type[context.Context] = context.Context
+    ):
         super().__init__(aws_event, aws_context, context_class)
 
         # LambdaHandler-specific initialization
